#
# spec file for package awstats
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           awstats
Summary:        Advanced Web Statistics
License:        GPL-3.0
Group:          Productivity/Networking/Web/Utilities
Version:        7.8
Release:        4.1
Url:            http://awstats.sourceforge.net
%if 0%{?suse_version}
BuildRequires:  apache2-devel
Recommends:     apache2
%define apache_mmn %(%{_libdir}/apache2_MMN | sed 's/apache_mmn_//')
# Needed perl modules for the plugins
Recommends:     perl-Net-DNS
Recommends:     perl-Net-IP
Recommends:     perl-Storable
Recommends:     perl-Geo-IP
Recommends:     %{name} = %{version}
%endif
%if 0%{?suse_version} > 1020
BuildRequires:  fdupes
%endif
%if 0%{?fedora_version}
BuildRequires:  httpd-devel
Requires:       httpd
%define apache_mmn %(rpm -q --provides httpd | grep mmn | awk -F " = " '{print $2}')
%endif
Requires:       cron
Requires:       logrotate
Requires:       perl >= 5.00.503
Requires:       perl(URI)
Requires:       perl(Net::DNS)
Requires:       perl(Net::IP)
Source:         awstats-%{version}.tar.gz
Source4:        cron.d.awstats
Source5:        awstats-update
Source6:        awstats-update.8
Source7:        awstats.logrotate
Source8:        awstats-rpmlintrc
Source9:        awstats.README
Patch2:         %{name}-3473378-urldecode.patch
# PATCH-FIX-OPENSUSE awstats-fix_css_icon_path.patch -- fix path to icons inside the css
Patch3:         %{name}-fix_css_icon_path.patch
Patch4:         %{name}-config_path.patch
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%define         apache_htdocsdir %(/usr/sbin/apxs2 -q HTDOCSDIR)
%define         apache_sysconfdir %(/usr/sbin/apxs2 -q SYSCONFDIR)
%define         apache_cgidir %(/usr/sbin/apxs2 -q CGIDIR)
%if             0%{?apache_mmn} >= 20120211
%define         apache_access Require all granted
%else
%define         apache_access Order allow,deny\
        Allow from all
%endif

%description
Advanced Web Statistics (AWStats) is a powerful Web server log file
analyzer (Perl script) that shows Web statistics including visitors,
pages, hits, hours, search engines, keywords used to find your site,
broken links, robots, and more.

This log analyzer works as a CGI or from command line and shows you
all possible information your log contains, in few graphical web
pages like visits, unique vistors, authenticated users, pages,
domains/countries, OS busiest times, robot visits, type of files,
search engines,keywords and keyphrases used, visits duration,
cluster balancing, HTTP errors and also screen size, web browser
java,flash,etc support and more...
Statistics can be updated from a browser or your scheduler.
AWStats uses a partial information file to be able to process large
log files, often and quickly.

It can analyze log files from IIS (W3C log format), Apache log files
(NCSA combined/XLF/ELF log format or common/CLF log format), WebStar
and most of all web, proxy, wap, streaming servers (and ftp servers
or mail logs).
The program also supports virtual servers, plugins and a lot of
features.

%package doc
Summary:        Documentation package for awstat
Group:          Productivity/Networking/Web/Utilities
Provides:       w3af-gtk = %{version}
Obsoletes:      w3af-gtk < %{version}
Requires:       %{name} = %{version}

%description doc
This package contains the documentation for awstats

%prep
%setup -q
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
# if the following command fails, then apache dependencies are not met
/usr/sbin/apxs2 -q datadir >/dev/null

%install
function create_config(){
	LOGFILE=$1
    LOGTYPE=$2
    CONFNAME=$3
    PLUGINS=$4
	# Using sed rather than a diff here, to make sure all relevant
	# options are checked (upstream defaults have moved around in
	# the past)MiscTrackerUrl="/js
	sed -e "s|^LogFile.*|LogFile=\"$LOGFILE\"|g" \
    -e 's|^LogFormat.*|LogFormat=1|g' \
    -e "s|^LogType.*|LogType=$LOGTYPE|g" \
    -e 's|^DNSLookup.*|DNSLookup=1|g' \
    -e 's|^DirData.*|DirData="%{_var}/cache/awstats"|g' \
    -e 's|^DirIcons.*|DirIcons="/awstats/icon"|g' \
    -e 's|^DirLang.*|DirLang=%{_datadir}/awstats/lang"|g' \
    -e 's|^ErrorMessages.*|ErrorMessages="An error occurred. Contact your Administrator"|g' \
    -e 's|^HostAliases.*|HostAliases="localhost 127.0.0.1"|g' \
    -e 's|^#Include\s*|Include="%{_sysconfdir}/awstats/awstats.conf.local"|g' \
    -e 's|^NotPageList.*|NotPageList="css js class gif jpg jpeg png bmp ico rss xml swf"|g' \
	-e 's|^MiscTrackerUrl.*|MiscTrackerUrl="/awstats/js/awstats_misc_tracker.js"|g' \
    -e 's|^ShowFlagLinks.*|ShowFlagLinks="de en es fr nl"|g' \
    -e 's|^StyleSheet.*|StyleSheet="/awstats/css/awstats_bw.css"|g' \
    -e 's|^AllowToUpdateStatsFromBrowser.*|AllowToUpdateStatsFromBrowser=1|g' \
    -e 's|^EnableLockForUpdate.*|EnableLockForUpdate=1|g' \
    -e 's|^SaveDatabaseFilesWithPermissionsForEveryone.*|SaveDatabaseFilesWithPermissionsForEveryone=1|g' \
    wwwroot/cgi-bin/awstats.model.conf > %{buildroot}%{_sysconfdir}/awstats/$CONFNAME
#    -e 's|^AllowAccessFromWebToAuthenticatedUsersOnly.*|AllowAccessFromWebToAuthenticatedUsersOnly=1|g' \
	for pluginname in $PLUGINS; do
		sed -i "s|^#LoadPlugin\s*=\s*\"$pluginname\"|LoadPlugin=\"$pluginname\"|g" %{buildroot}%{_sysconfdir}/awstats/$CONFNAME
	done
}

# create the directories needed for installation
mkdir -p %{buildroot}%{cgidir}/classes
mkdir -p %{buildroot}%{_sysconfdir}/awstats
mkdir -p %{buildroot}%{apache_sysconfdir}/conf.d/
mkdir -p %{buildroot}%{apache_cgidir}/classes
mkdir -p %{buildroot}%{_datadir}/awstats/classes
mkdir -p %{buildroot}%{_var}/cache/awstats
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}/examples
# create some example configs
create_config "%{_var}/log/apache2/awstats.log" "W" "awstats.web.conf" "tooltips ipv6 hashfiles"
create_config "%{_var}/log/vsftpd.log" "F" "awstats.vsftp.conf" "tooltips ipv6"
create_config "%{_var}/log/mail" "M" "awstats.smtp.conf" "tooltips ipv6"
# install the files
cp -r wwwroot/{icon,css,js}              %{buildroot}%{_datadir}/awstats/
cp -r wwwroot/cgi-bin/{lang,lib,plugins} %{buildroot}%{_datadir}/awstats/
cp -r wwwroot/classes/*.jar              %{buildroot}%{_datadir}/awstats/classes/
install -Dm755 wwwroot/cgi-bin/awstats.pl         %{buildroot}%{apache_cgidir}/

# fix permissions
chmod -x %{buildroot}%{_datadir}/awstats/plugins/*.pm
chmod -x %{buildroot}%{_datadir}/awstats/lang/*.txt

# fix wrong line encoding (dos)
for file in $(find %{buildroot}%{apache_cgidir}/plugins/ -type f -name "*.pm"); do
	sed -i 's/\r$//' $file
done
for file in $(find docs/* -maxdepth 1 -type f); do
	sed -i 's/\r$//' $file
done

# install additional sources
install -Dm644 %{SOURCE4} %{buildroot}%{_sysconfdir}/cron.d/suse.de-awstats
install -Dm755 %{SOURCE5} %{buildroot}%{_sbindir}/awstats-update
install -Dm644 %{SOURCE6} %{buildroot}%{_mandir}/man8/awstats-update.8
install -Dm644 %{SOURCE7} %{buildroot}/etc/logrotate.d/awstats
cat > %{buildroot}%{apache_sysconfdir}/conf.d/awstats.conf << EOF
#
# The location and format of the access logfile (Common Logfile Format).
# If you do not define any access logfiles within a <VirtualHost>
# container, they will be logged here.  Contrariwise, if you *do*
# define per-<VirtualHost> access logfiles, transactions will be
# logged therein and *not* in this file. In this case you have to
# modify awstats yourself to point to the correct, combined log file.
#
<IfDefine AWSTATS>
    CustomLog /var/log/apache2/awstats.log combined

    Alias /awstats/icon/ "%{_datadir}/awstats/icon/"
    <Directory "%{_datadir}/awstats/icon">
        Options Indexes MultiViews
        AllowOverride None
        %{apache_access}
    </Directory>

    Alias /awstats/lang/ "%{_datadir}/awstats/lang/"
    <Directory "%{_datadir}/awstats/lang">
        AllowOverride None
        %{apache_access}
    </Directory>

    Alias /awstats/css/ "%{_datadir}/awstats/css/"
    <Directory "%{_datadir}/awstats/css/">
        AllowOverride None
        %{apache_access}
    </Directory>

    Alias /awstatsclasses "%{_datadir}/awstats/classes"
    <Directory "%{_datadir}/awstats/classes">
        AllowOverride None
        %{apache_access}
    </Directory>

    Alias /awstats/js/ "%{_datadir}/awstats/js/"
    <Directory "%{_datadir}/awstats/js/">
        AllowOverride None
        %{apache_access}
    </Directory>
</IfDefine>
EOF

# install docu
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}/examples
# install the scripts in tools into the examples dir
mv %{buildroot}%{_datadir}/awstats/plugins/example/* %{buildroot}%{_defaultdocdir}/%{name}/examples/
rm -rf %{buildroot}%{_datadir}/awstats/plugins/example
for file in $(find tools/ -name *.pl); do
	sed -e 's/\r$//' $file > %{buildroot}%{_defaultdocdir}/%{name}/examples/$(basename $file)
	chmod +x %{buildroot}%{_defaultdocdir}/%{name}/examples/$(basename $file)
done
install -m644 README.md %{buildroot}%{_defaultdocdir}/%{name}/
cp -r docs %{buildroot}%{_defaultdocdir}/%{name}/
chmod -x   %{buildroot}%{_defaultdocdir}/%{name}/docs/*.pdf
chmod -x   %{buildroot}%{_defaultdocdir}/%{name}/docs/*.html
chmod -x   %{buildroot}%{_defaultdocdir}/%{name}/docs/images/*
chmod -x   %{buildroot}%{_defaultdocdir}/%{name}/docs/*.txt 
install -m644 wwwroot/cgi-bin/awstats.model.conf %{buildroot}%{_defaultdocdir}/%{name}/
install -m644 %{SOURCE9} %{buildroot}%{_defaultdocdir}/%{name}/README.SUSE
rm %{buildroot}%{_defaultdocdir}/%{name}/docs/COPYING.TXT

%if 0%{?suse_version} > 1020
%fdupes -s %{buildroot}%{_defaultdocdir}/%{name}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
# Former workaround for CVE-2020-29600/CVE-2020-35176, kept as best practice
if [ ! -f %{_sysconfdir}/awstats/awstats.conf ]; then
    cat > %{_sysconfdir}/awstats/awstats.conf << EOF
# The existence of this file prevents awstats from attempting to look in other
# directories for its configurations, which previously led to exploits.
#
# You may replace this file with your own configuration, or remove it if you
# really want awstats to search the directories listed in @PossibleConfigDir
# in %{apache_cgidir}/awstats.pl.
EOF
fi

%files
%defattr(-,root,root)
%doc %{_mandir}/man8/awstats-update.8.gz
%dir %{_sysconfdir}/awstats
%dir %{apache_sysconfdir}/conf.d
%dir %{_datadir}/awstats
%config(noreplace) %{_sysconfdir}/logrotate.d/awstats
%config(noreplace) %{apache_sysconfdir}/conf.d/awstats.conf
%if 0%{?suse_version} >= 1550
%dir %{_sysconfdir}/cron.d
%endif
%config(noreplace) %{_sysconfdir}/cron.d/suse.de-awstats
%config(noreplace) %{_sysconfdir}/awstats/awstats.web.conf
%config(noreplace) %{_sysconfdir}/awstats/awstats.vsftp.conf
%config(noreplace) %{_sysconfdir}/awstats/awstats.smtp.conf
%{_sbindir}/awstats-update
%{_datadir}/awstats/*
%{apache_cgidir}/*
%defattr(-,wwwrun,www)
%dir %{_var}/cache/awstats

%files doc
%defattr(0644,root,root, 0755)
%doc %{_defaultdocdir}/%{name}

%changelog
* Mon Aug  2 2021 adaugherity@tamu.edu
- Include upstream (post-7.8) fix for CVE-2020-35176.
  - Note that the OBS package since 2018-03-05 was NOT vulnernable to either
    this or CVE-2020-29600, as it created a placeholder awstats.conf which
    prevented awstats from looking elsewhere.
- Update the comment in said placeholder conf and add these CVE references to
  the Mar 5, 2018 changelog entry.
* Wed Feb 24 2021 lars@linux-schulserver.de - 7.8
- update to version 7.8
  + NEW Add SelectBox for DatabaseBreak Mode: month,day and hour.
  + Update http status codes
  + Add more file types
  + Update README.md
  + Fix geoip2 formatting problem
  + corner case 99
  + Fix some incoherent entries in search_engines.pm
  + Fix geoip2 plugin on windows by renaming it
  + Update robots.pm with PR118 data.
  + Change markdown to better readability
  + Change to https links
  + Fix links for perl download
  + NEW add %%time6 tag in log format to support some IIS log format
  + geoip2: Fix table formatting error. Missing "<td>" item tag.
  + Changes to robots.pm
  + Add support for macOS DMG and PKG files
  + Fix browser detection with HTTP 206 status code
  + Support for macOS 10.13/10.14 + improved image compression of icons
  + Fix use the 5 top hits as base 100 for graph to show the top 5 hits.
  + Clean up geoip2 and geoip2 city modules
  + Losslessly reduced size of PNG images by about 33%% using zopfli, pngout
    and oxipng. Also added os icons for macOS 10.13 and 10.14.
  + Add Robot: The Knowledge AI
  + Fix Error: Not same number of records of RobotsSearchIDOrder_listx
  + Robots, Search Engine and Web Page Tracking Modifications
  + Added UptimeRobot https://uptimerobot.com/
  + Fix a few grammar errors in the model config
  + Ignore search phrases longer than 80 characters.
  + Fix 404 detail page not updating
  + Decode RFC 3986 "unreserved chars" in URLs.
  + Disable nested includes warnings for Perl > 5.6.
  + Update domains.pm
  + Fix two invalid entries in search_engines.pm
  + Format Tera Bytes
  + Fix "Illegal division by zero" error.
  + Improving error handling in awstats_buildstaticpages.pl
  + Exclude private IP addresses since GeoIP2::Reader doesn't support them
  + Ignore search phrases longer than 80 characters.
  + Only purge data for the saved section.
  + Make city plugin more functional
  + Fix issue with ShowHost section when address is resolved.
  + Initial implementation of GeoIP2 City lookup.
  + Fix a few issues with Country lookup.
  + Initial implementation. Looksup only Country code for IPv4 and IPv6
  + Update hebrew file
  + Quite a few additions and modifications. Especially yahoo detection.
  + Added device pixel ratio ( dpr ) to awstats_misc_tracker.js.
  + added 37 new robots to robots.pm file using v 7.7 robots.pm file as base file.
  + Move oBot entry lower as to not incorrectly get picked for other *obot robots.
  + Decode RFC 3986 "unreserved chars" in URLs.  This makes awstats treat "/foo" and "/%%66%%6f%%6f" as equivalent.
  + Missing Sint Maarten  flag
  + Wrong label cf. https://dev.maxmind.com/geoip/legacy/codes/iso3166/
  + Fix country name not correct
  + Fix utf bom files
  + Fix another vulnerability reported by cPanel Security Team (can execute arbitraty code)
  + Add more tests
- refreshed patches:
  + awstats-3473378-urldecode.patch
  + awstats-fix_css_icon_path.patch
* Mon Nov 30 2020 ro@suse.de
- add cron.d when building on factory
* Sun Jul  5 2020 lars@linux-schulserver.de - 7.7
- require needed perl modules: perl(Net::DNS) and perl(Net::IP)
- use perl module requires for perl-URI -> perl(URI)
- Apache is not required to run awstats. Lower dependency to only
  recommend apache2
* Mon Mar  5 2018 adaugherity@tamu.edu
- Update to version 7.7
  - Security fix: CVE-2017-1000501
  - Security fix: Missing sanitizing of parameters
  - Fix LogFormat=4 with url containing spaces.
  - Fix to window.opener vulnerability in external referral site links.
  - Add methodurlprot in key to define log format.
  - Add Dynamic DNS Lookup.
  - Fix edge support.
- Rebase awstats-3473378-urldecode.patch
- Create placeholder awstats.conf file to work around incomplete fix for
  CVE-2017-1000501 (https://github.com/eldy/awstats/issues/90).  This issue
  was later assigned CVE-2020-29600 (full paths) and CVE-2020-35176
  (unqualified paths).
* Mon Jan  9 2017 adaugherity@tamu.edu
- Update to version 7.6
  - Security fix: "|" not allowed into DirLang parameter.
  - Security fix: More restrictive rule for using AWSTATS_ENABLE_CONFIG_DIR.
  - Update robots database.
  - Fix OS database.
  - Update/fix of documentation.
  - Add missing country flag for "el".
  - Add partial support for pure-ftpd stats format in method field.
  - Add support for macOS Sierra.
  - Add web fonts to default NotPageList, add support for GPX and JSON files
* Fri Jul  8 2016 adaugherity@tamu.edu
- Update to version 7.5
  - Compatibility with Perl 5.22
  - Support detection of Edge browser with detail of version.
  - Update robots database
  - Add eot/woff/woff2 to mime.pm as fonts
  - Add .svgz to image list
  - Exclude groups.google from search engines
  - Add %%time5 tag to support log format with iso time with timezone.
  - Add option DynamicDNSLookup to make DNS lookup during output instead
    of during log analysis processing.
  - Increase default value for MaxRowsInHTMLOutput
* Tue Sep 22 2015 adaugherity@tamu.edu
- Update apache configuration syntax for apache 2.4.
  * This should still use old-style syntax on distros with apache 2.2.
  * Fix tabs/spaces.
* Wed Jul 29 2015 wittemar@googlemail.com
- update to version 7.4
  * New features:
  - Add debian patch debian-patches-1019_allow_frame_resize.patch to add
    option nboflastupdatelookuptosave on command line.
  - #199 Added geoip6 plugin with support for IPv4 AND IPv6.
  - Work with Amazon AWS log files (using %%time5 tag).
  * Fixes:
  - Fixes permission on some .pl scripts.
  - #205 GetResolvedIP_ipv6 does not strip trailing dot.
  - #496 tools scripts should print warnings and errors to STDERR.
  - #919 Referrals not getting tracked due to improperly getting flagged as a search.
  - Add debian patch 0007_russian_lang.patch.
  - Add debian patch 2001_awstatsprog_path.patch.
  - #921 Failure in the help text for geoip_generator.pl
  - #909 awstats_buildstaticpages.pl noisy debug output.
  - #680 Invalid data passed to Time::Local causes global destruction.
  - #212 Fix CVE-2006-2237
* Mon Mar 31 2014 jweberhofer@weberhofer.at
- update to version 7.3
  * New features:
  - Add command line option -version
  - Better error management of geoip modules.
  - Update domains, robots and search engines database:
  - #877 Windows 8 + iOS Support in AWStats
  - Detection of 8.1 and IE11.
  * Fixes:
  - When using builddate option of script awstats_buildstaticpages,
    static link is wrong.
  - Restore detection of Opera browsers versions.
  - #838 GeoIP Cities page doesnt work.
  - Add missing icons.
  - #881 Avoid warning mixed http/https with module graphgooglechartapi.
  - #918 $MinHit{'Host'} rather than $MinHit{'Login'} used in sub
    HTMLShowLogins.
  * Other:
  - Move version system to sourceforge Git instead of CVS.
- update to version 7.2
  * New features:
  - Upgrade licence to GPL v3+.
  - Update documentation.
  - Support modCloudFlareIIS.
  * Fixes:
  - Since updating Webmin to 1.53, the Add New Config File screen layout is
    totally messed up and unusable.
  - Update broken links to maxmind.
- rebased awstats-CVE-2006-2237_read_open.patch
- rebased awstats-3473378-urldecode.patch
- removed FSF-address patch
- renamed README.SUSE
- fixed license
- splitted in main package and doc
* Thu May 30 2013 benoit.monin@gmx.fr
- Add awstats-fix_css_icon_path.patch: Change path to icons inside
  css to match the apache configuration.
* Wed May 29 2013 benoit.monin@gmx.fr
- Require perl-URI; package is mandatory because of urldecode.patch
* Mon Apr 29 2013 jweberhofer@weberhofer.at
- Fixed license; following the LICENSE file, it's GPL-2.0.
* Fri Apr 26 2013 jweberhofer@weberhofer.at
- update to version 7.1.1
  * Add windows 8 detection
  * Add support of %%time5 for iso date times.
  * Fix problems with Perl 5.14
* Tue Jul 17 2012 jweberhofer@weberhofer.at
- update to version 7.1.beta2
- New features/improvements:
  * Update translations.
  * Update browsers list.
  * Add example of nginx setup.
  * Add some patches from debian package.
  * Rename domain name into documentation to awstats.org
  * Can allow urls with awredir without using md5 key parameter.
  * Usage of databasebreak option possible with awstats_buildstaticpages.
  * Add rel=nofollow on links.
  * Add option AddLinkToExternalCGIWrapper to add link to a wrapper script
    into each title of Dolibarr reports. This can be used to add a wrapper
    to download data into a CSV file for example.
- Fixes:
  * Security fix into awredir.pl
  * Fix: Case of uk in googlechart api
- Fix for Perl 5.14+:
  * http://sourceforge.net/tracker/index.php?func=detail&aid=3311848&group_id=13764&atid=113764
- Better output of Encoded Characters: #3520721
* Fri Dec 17 2010 mrdocs@opensuse.org
- update to version 7.0
- refresh the awstats-CVE-2006-2237_read_open.patch so it applies
- fix a small mountain of wrong permissions in the source
  +New features/improvements:
  +Detect Windows 7.
  +Can format numbers according to language.
  +More mime types.
  +Added geoip_asn_maxmind plugin.
  + Geoip Maxmind city plugin have now override file capabilities to complete
  missing entries in geoip maxmind database.
  + Added graphgooglechartapi to use online Google chart api to build graph.
  +Can show map of country to report countries when using graphgooglechartapi.
  +Part of codes was change to use more functions and have a cleaner code.
  +-Added parameter to ignore missing log files when merging for a site on
  multiple servers where a single server may not have created a log for a given day.
  +Update robots database.
  +Added Download tracking where certain mime types are defined as downloads
  and HTTP status 206 is tracked as download continuation
  +Can use wrapper with parameters in WrapperScript parameter.
  +Change to allow usage of AWStats inside a plugin
  for Opensource Dolibarr ERP & CRM software (http://www.dolibarr.org).
  Thanks to Chris Larsen (author of most thoses changes).
  Fixes:
  + Webmin module works with new version of webmin.
  + Security fix (Traverse directory of LoadPlugin)
  + Security fix (Limit config to defined directory to avoid access to external
  + config file via a nfs or webdav link).
* Sat Jan 30 2010 javier@opensuse.org
- Fixed Alias /awstats/icon/ in awstats.conf
  Sun Jan
* Sun Jan 24 2010 mrdocs@opensuse.org
- bump version
- new version has new detection for new browsers and
  search engine (Bing, Chrome etc.)
* Tue Jan 13 2009 lars@linux-schulserver.de
- fix icons alias in apache config (thanks to Jan Engelhardt)
* Mon Dec 29 2008 lars@linux-schulserver.de
- enhanced the awstats-update script (chown wwwrun:www if needed)
- rename configs, so awstats-update script can find them
- don't run fdupes to avoid FollowSymlinks in apache's config
- place nearly everything under /usr/share/awstats to get a clean
  cgi-dir
* Sun Dec 28 2008 lars@linux-schulserver.de
- update to version 6.9
  + With postfix that support DSN (Delivery Status Notifications)
    we exclude some lines to avoid counting mails twice in
  maillogconvert.pl script.
  + Logresolvemerge.pl support FreeRADIUS logs or anything else using
    (the fixed length!) ctime format timestamp.
  + Add option stoponfirsteof in logresolvemerge tool.
  + Add patch to support host_proxy tag in LogFormat (for Apache
    LogFormat containing %%{X-Forwarded-For}i)
  + Renamed Add to favourites on "Hit on favicon".
  + Increase robots, search engines database (Added Google Chrome
    browser, better Vista, WII, detection, ...)
  + Update languages files.
  + Added a lot of patches from sourceforge.
- rework the specfile
- use sed to adapt the config inline (no patches any more)
- reworked awstats-CVE-2006-2237_read_open.patch
- added README.SuSE
- added perl modules for Plugins as Recommended
- Require logrotate and cron
- Removed module.awstats -> apache1 is gone
- silence the cronjob
* Sun Nov  9 2008 mrdocs@opensuse.org
- Update to version 6.8
- test patches apply
- pending backport for CVE
* Mon Jul  9 2007 mskibbe@suse.de
- update to version 6.7
  * Full support for -day option. To build different
    report for each day
  * Added virtualenamequot tag
  * Added option NotPageList
  * Addes .jobs and .mobi domains
  * Minor bug in awstats_configure.pl
  * Updated some language files
  * Updated browsers database
* Thu Mar  8 2007 mskibbe@suse.de
- awstats: missing dependency (#250629)
* Wed Oct 25 2006 ro@suse.de
- use java2-devel-packages in buildreq
* Tue Oct 10 2006 mskibbe@suse.de
- fix Bug 211218 - awstats won't load piped output
- fix Bug 211219 - awstats won't place it's icons into
  /srv/www/htdocs/icons
* Wed Sep 13 2006 mskibbe@suse.de
- install the classes directory
- fix Requires BuildRequires
* Fri Aug  4 2006 mskibbe@suse.de
- add example configs for ftp and smtp
* Mon Jul 31 2006 mskibbe@suse.de
- bugfix for geoip function (Bug #188142) which fix a syntax error
* Wed Jun 14 2006 mrueckert@suse.de
- Upgraded to version 6.6, list of new things among others:
  - RSS catcher/readers in robot database
  - Enhanced GeoIP support.
  - LevelForBrowsersDetection can accept value 'allphones' to use file browsers_phone.pm instead of browsers.pm file for AWStats database.
  - Add option ShowSummary.
  - If LogFormat is 2, AWStats autodetect log format change.
  - Add a way to set ArchiveLogRecords with same tags than LogFile to add suffix to archived log files.
- Security fix for CVE-2006-2237: missing sanitizing of the "migrate"
  parameter. #173041
- Security fix for CVE-2006-2644: missing sanitizing of the "configdir"
  parameter. #173041
- Make sure open() only opens files for read/write by adding explicit
  < and >.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 27 2005 hmuelle@suse.de
- Update to official Version 6.5
- removed patch
    awstats-Secfix20050811.dif
  as it was just a backport from 6.5 beta
* Sun Aug 14 2005 hmuelle@suse.de
- Applied security fix [Bug #103788]
  AWStats ShowInfoURL Remote Command Execution Vulnerability
* Sun Jul 17 2005 hmuelle@suse.de
- Update to version 6.4
* Tue Jun  7 2005 ro@suse.de
- rename cron script to local namespace for LSB conformance
* Mon Jan 31 2005 hmuelle@suse.de
- Update to version 6.3
  the security-patch from somedays ago is no longer needed
* Thu Jan 20 2005 hmuelle@suse.de
- Applied a security fix [Bug #49967]
  Remote Command Execution Vulnerability
* Mon Nov  8 2004 hmuelle@suse.de
- Update to version 6.2
* Sun Aug 29 2004 ro@suse.de
- removed obsolete postinstall script and now obsolete prereq
* Sat Aug 28 2004 hmuelle@suse.de
- Removed sysconfig.apache-awstats , missed it by last change
* Tue Aug 17 2004 hmuelle@suse.de
- Removed old apache1 stuff, as no longer supported with newer
  versions of SUSE Linux
* Tue Aug 17 2004 hmuelle@suse.de
- Update to version 6.1
* Sun Feb 29 2004 hmuelle@suse.de
- Update to version 6.0
* Wed Feb  4 2004 hmacht@suse.de
- added option # norootforbuild in specfile
* Tue Dec  9 2003 kukuk@suse.de
- Update to version 5.9
- Add tools directory as documentation [Bug #32331]
* Tue Jul  1 2003 kukuk@suse.de
- Update to version 5.6
* Thu Jun 19 2003 ro@suse.de
- added apache2 to neededforbuild
- added directory to filelist
* Mon Mar 10 2003 poeml@suse.de
- fix path to awstats.log in awstats.logrotate, and add the apache2
  logfile. Reload both servers but only if they run.
- the "modules" mechanism via /etc/apache2/modules/* and sysconfig
  variables is no longer in use with apache2. Instead, put awstats into
  conf.d for automatic inclusion and enclose the content in
  <IfDefine AWSTATS>. It can be activated via APACHE_SERVER_FLAGS
  in sysconfig.apache.
* Mon Feb 24 2003 kukuk@suse.de
- Update to offical tar archive.
* Fri Feb 21 2003 kukuk@suse.de
- Update to new snapshot (minor bug fixes)
* Fri Feb 14 2003 kukuk@suse.de
- Update to new snapshot
* Wed Feb  5 2003 kukuk@suse.de
- Update to new snapshot (autodetect start language)
* Tue Jan 28 2003 kukuk@suse.de
- Update to new snapshot (small bug fixes)
* Fri Jan 17 2003 kukuk@suse.de
- Update to new snapshot
- Use different sysconfig Variables for Apache 1.x and 2.x
* Thu Jan  9 2003 kukuk@suse.de
- Enable DNS reverse lookup
- Enable tooltips
* Wed Jan  8 2003 kukuk@suse.de
- Update to 5.4 beta
- Fix path to log files
* Sun Dec 15 2002 kukuk@suse.de
- Add support for Apache2
- Fix icon path in default conf
* Sun Dec 15 2002 kukuk@suse.de
- Update to version 5.2
* Thu Aug 15 2002 kukuk@suse.de
- Add PreRequires
* Fri Aug  2 2002 kukuk@suse.de
- Don't use apxs, it does not work with this package
- Fix new web root path in shell scripts
- Adjust default configuration
* Thu Aug  1 2002 ro@suse.de
- adapt server-root
* Tue Jul 23 2002 kukuk@suse.de
- Update to version 4.1
* Wed Mar 13 2002 kukuk@suse.de
- Add /etc/awstats
* Thu Jan 17 2002 ro@suse.de
- adapted for /etc/sysconfig/apache
* Wed Dec 12 2001 kukuk@suse.de
- Add logrotate config file
* Fri Nov  2 2001 kukuk@suse.de
- Add update script, manual page and cronjob
* Wed Oct 31 2001 kukuk@suse.de
- Update to version 3.1
- Make package noarch
* Wed Aug 29 2001 kukuk@suse.de
- Add apache config files
* Mon Aug 13 2001 kukuk@suse.de
- Initial version
